==> lyskom-1.7.1.tar.gz: lyskom-1.7.1/scripts/makedist.sh <==
# makedist.sh -- build a distribution (use "make dist" to invoke this script).
# $Id: makedist.sh,v 1.1 1994/12/31 11:41:34 ceder Exp $
# Copyright (C) 1994  Lysator Academic Computer Association.
#
# This file is part of the LysKOM server.
# 
# LysKOM is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by 
# the Free Software Foundation; either version 1, or (at your option) 
# any later version.
# 
# LysKOM is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
# 
# You should have received a copy of the GNU General Public License
# along with LysKOM; see the file COPYING.  If not, write to
# Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
# or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
# MA 02139, USA.
#
# Please mail bug reports to bug-lyskom@lysator.liu.se. 
#
set -e
[ ! -f ${srcdir}/Makefile ]
( cd ${srcdir} && ./mkmi )
$RM -rf lyskom-$(SERVER-VER)
for i in "" /src /src/libraries /doc /scripts; do\
	mkdir lyskom-$(SERVER-VER)$i||exit 1;\
done
if [ -f ${srcdir}/README-serverrelease ] ;then \
	cp ${srcdir}/README-serverrelease lyskom-$(SERVER-VER)/README;\
else\
	cp ${srcdir}/README lyskom-$(SERVER-VER)/README;\
fi

for i in .cvsignore COPYING ChangeLog INSTALL Makefile.in Makefile.src \
	NEWS aclocal.m4 configure configure.in mkmi versions; \
    do cp ${srcdir}/$i lyskom-$(SERVER-VER)/||exit 1; done
cp ${srcdir}/src/Makefile.in lyskom-$(SERVER-VER)/src/
cp ${srcdir}/src/Makefile.src lyskom-$(SERVER-VER)/src/
cp ${srcdir}/src/libraries/Makefile.in \
    lyskom-$(SERVER-VER)/src/libraries/
cp ${srcdir}/src/libraries/Makefile.src \
    lyskom-$(SERVER-VER)/src/libraries/
for i in ADMINISTRATION Makefile.in misc_items prot-A.txt	\
	server-async.extend server.extend what-is-unread.swe 	\
	server-config.extend Makefile.src .cvsignore;		\
do 								\
	cp ${srcdir}/doc/$i lyskom-$(SERVER-VER)/doc/$i||exit 1;\
done
cp -r ${srcdir}/doc/man lyskom-$(SERVER-VER)/doc/man
$RM -r lyskom-$(SERVER-VER)/doc/man/man?
for i in Makefile.in Makefile.src install-sh makedist.sh \
	mkinstalldirs mkmi.m4; do\
    cp ${srcdir}/scripts/$i lyskom-$(SERVER-VER)/scripts/||exit 1; \
done
cp -r ${srcdir}/run-support lyskom-$(SERVER-VER)/run-support
for i in libansi libcommon libisc-new libmisc regex .cvsignore; do \
	cp -r ${srcdir}/src/libraries/$i \
		lyskom-$(SERVER-VER)/src/libraries \
	|| exit 1 ; \
done
cp -r ${srcdir}/src/server lyskom-$(SERVER-VER)/src
cp ${srcdir}/src/.cvsignore lyskom-$(SERVER-VER)/src/
$RM lyskom-$(SERVER-VER)/src/server/cache-database.h
$RM lyskom-$(SERVER-VER)/src/server/cache-database.c
$RM lyskom-$(SERVER-VER)/src/server/cache.c
cp -r ${srcdir}/src/include lyskom-$(SERVER-VER)/src/include
$RM -r lyskom-$(SERVER-VER)/src/include/ansi
cp -r ${srcdir}/db-crypt lyskom-$(SERVER-VER)
cp -r ${srcdir}/db-nocrypt lyskom-$(SERVER-VER)
find lyskom-$(SERVER-VER) \
    \( -name CVS -o -name '*~' -o -name '#*#' -o -name 'lib*.a' \
	 -o -name '*.o' -o -name '.#*' -o -name core -o -name '*.orig' \
	 -o -name Makefile.in2 -o -name 'stamp-*' -o -name 'TAGS' \) \
    -print -exec rm -rf "{}" \; -prune
tar cvf lyskom-$(SERVER-VER).tar lyskom-$(SERVER-VER)
$RM lyskom-$(SERVER-VER).tar.gz
gzip -9v lyskom-$(SERVER-VER).tar
$RM -r lyskom-$(SERVER-VER)
exit 0

==> lyskom-1.8.0.tar.gz: lyskom-1.8.0/scripts/makedist.sh <==
# makedist.sh -- build a distribution (use "make dist" to invoke this script).
# $Id: makedist.sh,v 1.3 1995/11/02 21:53:10 ceder Exp $
# Copyright (C) 1994, 1995  Lysator Academic Computer Association.
#
# This file is part of the LysKOM server.
# 
# LysKOM is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by 
# the Free Software Foundation; either version 1, or (at your option) 
# any later version.
# 
# LysKOM is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
# 
# You should have received a copy of the GNU General Public License
# along with LysKOM; see the file COPYING.  If not, write to
# Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
# or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
# MA 02139, USA.
#
# Please mail bug reports to bug-lyskom@lysator.liu.se. 
#
set -e
[ ! -f ${srcdir}/Makefile ]
( cd ${srcdir} && ./mkmi )
$RM -rf lyskom-$(SERVER-VER)
for i in "" /src /src/libraries /doc /scripts; do\
	mkdir lyskom-$(SERVER-VER)$i||exit 1;\
done
if [ -f ${srcdir}/README-serverrelease ] ;then \
	cp ${srcdir}/README-serverrelease lyskom-$(SERVER-VER)/README;\
else\
	cp ${srcdir}/README lyskom-$(SERVER-VER)/README;\
fi

for i in .cvsignore COPYING ChangeLog INSTALL Makefile.in Makefile.src \
	NEWS aclocal.m4 configure configure.in mkmi versions; \
    do cp ${srcdir}/$i lyskom-$(SERVER-VER)/||exit 1; done
cp ${srcdir}/src/Makefile.in lyskom-$(SERVER-VER)/src/
cp ${srcdir}/src/Makefile.src lyskom-$(SERVER-VER)/src/
cp ${srcdir}/src/libraries/Makefile.in \
    lyskom-$(SERVER-VER)/src/libraries/
cp ${srcdir}/src/libraries/Makefile.src \
    lyskom-$(SERVER-VER)/src/libraries/
for i in ADMINISTRATION Makefile.in misc_items prot-A.txt	\
	server-async.extend server.extend what-is-unread.swe 	\
	server-config.extend Makefile.src .cvsignore;		\
do 								\
	cp ${srcdir}/doc/$i lyskom-$(SERVER-VER)/doc/$i||exit 1;\
done
cp -r ${srcdir}/doc/man lyskom-$(SERVER-VER)/doc/man
$RM -r lyskom-$(SERVER-VER)/doc/man/man?
for i in Makefile.in Makefile.src install-sh makedist.sh \
	mkinstalldirs mkmi.m4; do\
    cp ${srcdir}/scripts/$i lyskom-$(SERVER-VER)/scripts/||exit 1; \
done
cp -r ${srcdir}/run-support lyskom-$(SERVER-VER)/run-support
for i in libansi libcommon libisc-new libmisc regex .cvsignore gnumalloc; do \
	cp -r ${srcdir}/src/libraries/$i \
		lyskom-$(SERVER-VER)/src/libraries \
	|| exit 1 ; \
done
cp -r ${srcdir}/src/server lyskom-$(SERVER-VER)/src
cp ${srcdir}/src/.cvsignore lyskom-$(SERVER-VER)/src/
$RM lyskom-$(SERVER-VER)/src/server/cache-database.h
$RM lyskom-$(SERVER-VER)/src/server/cache-database.c
$RM lyskom-$(SERVER-VER)/src/server/cache.c
$RM lyskom-$(SERVER-VER)/src/libraries/gnumalloc/Makefile
$RM lyskom-$(SERVER-VER)/src/libraries/gnumalloc/gmalloc.c
cp -r ${srcdir}/src/include lyskom-$(SERVER-VER)/src/include
$RM -r lyskom-$(SERVER-VER)/src/include/ansi
cp -r ${srcdir}/db-crypt lyskom-$(SERVER-VER)
cp -r ${srcdir}/db-nocrypt lyskom-$(SERVER-VER)
find lyskom-$(SERVER-VER) \
    \( -name CVS -o -name '*~' -o -name '#*#' -o -name 'lib*.a' \
	 -o -name '*.o' -o -name '.#*' -o -name core -o -name '*.orig' \
	 -o -name Makefile.in2 -o -name 'stamp-*' -o -name 'TAGS' \
	 -o -name '*.tmp' \) \
    -print -exec rm -rf "{}" \; -prune
tar cvf lyskom-$(SERVER-VER).tar lyskom-$(SERVER-VER)
$RM lyskom-$(SERVER-VER).tar.gz
gzip -9v lyskom-$(SERVER-VER).tar
$RM -r lyskom-$(SERVER-VER)
exit 0
